#Deskriptive Statistik
#Datensatz liver.csv

x <- read.csv (file.choose())

#Tabelle
View(x)

#Kennzahlen der deskriptiven Statistik
summary(x)
mean(x$ALP.B)
sd(x$ALP.B)

##frei whlbare Quantile
my.quantiles <- c(0, 0.025, 0.25, 0.5, 0.75, 0.975, 1)
quantile(x$ALP.B, my.quantiles)

##nicht-nummerische Werte (Tortengrafik)
table(x$dose)
pie(table(x$dose), clockwise=TRUE, main="Verteilung",
    labels=c("Dosis A","Dosis B","Dosis C","Dosis D"),
    col=c("lightyellow","yellow","orange","red"))

##Korrelationsmatrix
cor(x[,2:5])

##Regressionsgleichung 
### lm = linear model
lm(x$AST.B ~ x$ALT.B)

#Histogramm
hist(x$ALP.B, col="lightgreen",
            breaks=20,
            freq=FALSE,
            main="alk. Phosphatase",
            xlab="U/l", 
            ylab="rel. Hufigkeit")
lines(density(x$ALP.B))

#Boxplot vertikal/horizontal
boxplot(x$TBL.M, col="lightblue", 
        main="Bilirubin",
        ylab="mol/l")
        
boxplot(x$TBL.M, col="lightblue", 
        horizontal=TRUE,
        main="Bilirubin", 
        xlab="mol/l")
boxplot(x[,2:9])


#Boxplot in Abhngigkeit von der Dosis
boxplot(x$TBL.M ~ x$dose, col="lightblue",
        notch=TRUE,
        main="Bilirubin", xlab="Dosis", ylab="mol/l")
grid()
text(1, 35, "Medikation")

#Scatterplot
plot(x$ALP.M ~ x$ALP.B, col = "blue",
     xlab = "ALP Basis (U/l)",
     ylab = "ALP Medikation (U/l)")
reg.a.b <- lm(x$ALP.M ~ x$ALP.B)
abline(reg.a.b, lwd = 2)
abline(0, 1, lty = 2)
legend(85, 300, 
       c("y= -2.9 + 1.17 x", "y = x"),
       lty = c(1, 2))
grid()
abline(h = 120, col = "green", lwd = 3, lty = 3)
abline(v = 120, col = "green", lwd = 3, lty = 3)
text(115, 25, "(c) Georg Hoffmann 2018", col = "red")

#Scatterplots fr Bilirubin
plot(x$TBL.M ~ x$TBL.B)

plot(x$TBL.M ~ x$TBL.B, main = "Bilirubin (mol/l)", 
     xlab = "vor Medikation", ylab = "nach Medikation")


plot(x$TBL.M ~ x$TBL.B, 
     main = "Bilirubin (mol/l)", 
     xlab = "vor Medikation", 
     ylab = "nach Medikation",
     col = "blue")
grid()
abline(lm(x$TBL.M ~ x$TBL.B))
abline(0,1, lty = 2)

#Alle vier Scatterplots M ~ B
par(mfrow=c(2,2))
for (i in 1:4){
  plot(x[,i+5] ~ x[,i+1], xlab=colnames(x[i+1]), ylab=colnames(x[i+5]), col=i)
  grid()
  abline(lm(x[,i+5] ~ x[,i+1]))
  abline(0,1,lty=3)
}


#Kombination von Histogramm und Boxplot
hist(x$TBL.B, col="lightgreen",
     breaks=20,
     main="",
     xlab="TBIL (mol/l)", 
     ylab="Anzahl")
boxplot(x$TBL.B, col="lightgreen", horizontal=TRUE,
        add=TRUE, at=-2)
grid()
text(x=22, y=90, labels="Basiswerte vor Medikation", cex=1.8)
